Enum elements::EcdsaSigHashType
source · [−]pub enum EcdsaSigHashType {
All,
None,
Single,
AllPlusAnyoneCanPay,
NonePlusAnyoneCanPay,
SinglePlusAnyoneCanPay,
}Expand description
Hashtype of a transaction, encoded in the last byte of a signature Fixed values so they can be casted as integer types for encoding
Variants
All
0x1: Sign all outputs
None
0x2: Sign no outputs — anyone can choose the destination
Single
0x3: Sign the output whose index matches this input’s index. If none exists,
sign the hash 0000000000000000000000000000000000000000000000000000000000000001.
(This rule is probably an unintentional C++ism, but it’s consensus so we have
to follow it.)
AllPlusAnyoneCanPay
0x81: Sign all outputs but only this input
NonePlusAnyoneCanPay
0x82: Sign no outputs and only this input
SinglePlusAnyoneCanPay
0x83: Sign one output and only this input (see Single for what “one output” means)
Implementations
sourceimpl EcdsaSigHashType
impl EcdsaSigHashType
sourcepub fn from_u32(n: u32) -> EcdsaSigHashType
pub fn from_u32(n: u32) -> EcdsaSigHashType
Reads a 4-byte uint32 as a sighash type
sourcepub fn from_standard(n: u32) -> Result<EcdsaSigHashType, NonStandardSighashType>
pub fn from_standard(n: u32) -> Result<EcdsaSigHashType, NonStandardSighashType>