Module elements::hex

source ·
Hex Encoding and Decoding

Structs

  • Iterator over a hex-encoded string slice which decodes hex and yields bytes.
  • A struct implementing io::Write that converts what’s written to it into a hex String.

Enums

Traits

  • Trait for objects that can be deserialized from hex strings.
  • Trait for objects that can be serialized as hex strings.

Functions