AssetId

Struct AssetId 

pub struct AssetId(/* private fields */);
An issued asset ID.

Implementations

Source

impl AssetId

pub const LIQUID_BTC: AssetId

The asset ID for L-BTC, Bitcoin on the Liquid network.

pub fn from_byte_array(inner: [u8; 32]) -> Self

Constructs this wrapper struct from raw bytes.

pub const fn from_inner(midstate: Midstate) -> AssetId

Create an AssetId from its inner type.

pub fn into_inner(self) -> Midstate

Convert the AssetId into its inner type.

pub fn from_slice(sl: &[u8]) -> Result<AssetId, FromSliceError>

Copies a byte slice into an AssetId object

pub fn generate_asset_entropy( prevout: OutPoint, contract_hash: ContractHash, ) -> Midstate

Generate the asset entropy from the issuance prevout and the contract hash.

pub fn from_entropy(entropy: Midstate) -> AssetId

Calculate the asset ID from the asset entropy.

pub fn new_issuance(prevout: OutPoint, contract_hash: ContractHash) -> Self

Computes the asset ID when issuing asset from issuing input and contract hash

pub fn new_reissuance_token( prevout: OutPoint, contract_hash: ContractHash, confidential: bool, ) -> Self

Computes the re-issuance token from input and contract hash

pub fn reissuance_token_from_entropy( entropy: Midstate, confidential: bool, ) -> AssetId

Calculate the reissuance token asset ID from the asset entropy.

pub fn into_tag(self) -> Tag

Convert an asset into Tag