Module serialize

Module serialize 

PSET Serialization

Defines traits used for (de)serializing PSET values into/from raw bytes in PSET key-value pairs.

Traits

Deserialize
A trait for deserializing a value from raw data in PSET key-value pairs.
Serialize
A trait for serializing a value as raw data for insertion into PSET key-value pairs.

Functions

serialize_hex
Encode an object into a hex-encoded string