Type Alias elements::schnorr::UntweakedPublicKey
source · pub type UntweakedPublicKey = XOnlyPublicKey;Expand description
Untweaked Schnorr public key
Aliased Type
struct UntweakedPublicKey(/* private fields */);Trait Implementations
sourceimpl TapTweak for UntweakedPublicKey
impl TapTweak for UntweakedPublicKey
sourcefn tap_tweak<C: Verification>(
self,
secp: &Secp256k1<C>,
merkle_root: Option<TapNodeHash>
) -> (TweakedPublicKey, Parity)
fn tap_tweak<C: Verification>( self, secp: &Secp256k1<C>, merkle_root: Option<TapNodeHash> ) -> (TweakedPublicKey, Parity)
Tweaks an untweaked public key with corresponding public key value and optional script tree merkle root.
This is done by using the equation Q = P + H(P|c)G, where
- Q is the tweaked public key
- P is the internal public key
- H is the hash function
- c is the commitment data
- G is the generator point
Returns
The tweaked key and its parity.
type TweakedAux = (TweakedPublicKey, Parity)
type TweakedAux = (TweakedPublicKey, Parity)
Tweaked key type with optional auxiliary information
type TweakedKey = TweakedPublicKey
type TweakedKey = TweakedPublicKey
Tweaked key type
sourcefn dangerous_assume_tweaked(self) -> TweakedPublicKey
fn dangerous_assume_tweaked(self) -> TweakedPublicKey
Directly converts to a
TweakedKey Read more