TxOutWitness

Struct TxOutWitness 

pub struct TxOutWitness {
    pub surjection_proof: Option<Box<SurjectionProof>>,
    pub rangeproof: Option<Box<RangeProof>>,
}
Transaction output witness

Fields

surjection_proof: Option<Box<SurjectionProof>>

Surjection proof showing that the asset commitment is legitimate

rangeproof: Option<Box<RangeProof>>

Rangeproof showing that the value commitment is legitimate

Implementations

Source

impl TxOutWitness

pub fn empty() -> Self

Create an empty output witness.

pub fn is_empty(&self) -> bool

Whether this witness is null

pub fn rangeproof_len(&self) -> usize

The rangeproof len if is present, otherwise 0

pub fn surjectionproof_len(&self) -> usize

The surjection proof len if is present, otherwise 0