Consensus-encodable types
Re-exports
pub use bitcoin;
Enums
- Encoding error
Constants
- Maximum size, in bytes, of a vector we are allowed to decode.
Traits
- Data which can be encoded in a consensus-consistent way
- Data which can be encoded in a consensus-consistent way
- Extensions of
Readto decode data as per Bitcoin consensus. - Extensions of
Writeto encode data as per Bitcoin consensus.
Functions
- Deserialize an object from a vector, will error if said deserialization doesn’t consume the entire vector.
- Deserialize an object from a vector, but will not report an error if said deserialization doesn’t consume the entire vector.
- Encode an object into a vector
- Encode an object into a hex-encoded string