Hex Encoding and Decoding
Structs
- Iterator over a hex-encoded string slice which decodes hex and yields bytes.
- A struct implementing
io::Writethat converts what’s written to it into a hex String.
Enums
- Hex decoding error.
Traits
- Trait for objects that can be deserialized from hex strings.
- Trait for objects that can be serialized as hex strings.
Functions
- Outputs hex into an object implementing
fmt::Write. - Outputs hex in reverse order.