Partially Signed Elements Transactions (PSET)
Implementation of BIP174 Partially Signed Bitcoin Transaction Format as defined at https://github.com/bitcoin/bips/blob/master/bip-0174.mediawiki except we define PSETs containing non-standard Sighash types as invalid. Extension for PSET is based on PSET defined in BIP370. https://github.com/bitcoin/bips/blob/master/bip-0174.mediawiki
Modules
- An implementation of ELIP0100 as defined in https://github.com/ElementsProject/ELIPs/blob/main/elip-0100.mediawiki but excluding contract validation.
- An implementation of ELIP0101 as defined in https://github.com/ElementsProject/ELIPs/blob/main/elip-0101.mediawiki
- Raw PSET Key-Value Pairs
- PSET Serialization
Structs
- A key-value map for global data.
- Global transaction data
- A key-value map for an input of the corresponding index in the unsigned transaction.
- A key-value map for an output of the corresponding index in the unsigned transaction.
- A Partially Signed Transaction.
- A Signature hash type for the corresponding input.
- Taproot Tree representing a finalized
TaprootBuilder(a complete binary tree)
Enums
- Ways that a Partially Signed Transaction might fail.
- Ways that blinding a Partially Signed Transaction might fail.